@@ -217,11 +217,13 @@ class ParameterSweep(object):
         f_ST_inStrand = cable.f_ST / (cable.f_SC + cable.f_ST)
         I = abs(I)
         J_op = I / A_CableBare
-
+        print(cable.A_CableInsulated)
+        print(A_CableBare)
+        print(cable.f_SC)
+        print(cable.f_ST)
         Tc = cable.Tc0_NbTi * (1 - B / cable.Bc20_NbTi) ** cable.alpha_NbTi
         Tcs= (1 - I / (cable.c1_Ic_NbTi + cable.c2_Ic_NbTi * B)) * Tc
         Ts = (Tcs + Tc) / 2
-
         cp_ST = self.cpCu_nist_mat(Ts)
         cp_SC = self.cpNbTi_cudi_mat(Ts, B)
         cp = cp_ST * f_ST_inStrand + cp_SC * f_SC_inStrand
@@ -268,22 +270,26 @@ class ParameterSweep(object):
         return newCable
 
     def adjust_vQ(self, ROXIE_File):
+        B = self.acquireBField(ROXIE_File)
         if max(self.ParametersLEDET.Inputs.nStrands_inGroup) > 1:
-            if np.all(self.ParametersLEDET.Inputs.nStrands_inGroup == self.ParametersLEDET.Inputs.nStrands_inGroup[0]):
-                B = self.acquireBField(ROXIE_File)
-                B = B[::int(self.ParametersLEDET.Inputs.nStrands_inGroup[0])]
-            else:
-                print('vQ calculation only supports equally-stranded wires so far!. Abort.')
-                return
-        else:
-            B = self.acquireBField(ROXIE_File)
+            strandCount = 0
+            GroupCount = 0
+            Bcopy = np.zeros(int(sum(self.ParametersLEDET.Inputs.nT)))
+            for i in range(int(sum(self.ParametersLEDET.Inputs.nT))):
+                Bcopy[i] = sum(B[int(strandCount):int(strandCount+self.ParametersLEDET.Inputs.nStrands_inGroup[GroupCount])])/self.ParametersLEDET.Inputs.nStrands_inGroup[int(GroupCount)]
+                TurnSum = sum(self.ParametersLEDET.Inputs.nT[0:GroupCount+1])
+                if i>TurnSum: GroupCount = GroupCount + 1
+                strandCount = strandCount + self.ParametersLEDET.Inputs.nStrands_inGroup[GroupCount]
+            B = Bcopy
         I = self.ParametersLEDET.Inputs.I00
         T_bath = self.ParametersLEDET.Inputs.T00
         cable = Cable()
         cable.A_CableInsulated = (self.ParametersLEDET.Inputs.wBare_inGroup+2*self.ParametersLEDET.Inputs.wIns_inGroup) \
-                                * (self.ParametersLEDET.Inputs.hBare_inGroup+2*self.ParametersLEDET.Inputs.hIns_inGroup)
+                               * (self.ParametersLEDET.Inputs.hBare_inGroup+2*self.ParametersLEDET.Inputs.hIns_inGroup)
         cable.f_SC = self.ParametersLEDET.Inputs.f_SC_strand_inGroup * \
                         (self.ParametersLEDET.Inputs.wBare_inGroup*self.ParametersLEDET.Inputs.hBare_inGroup)/cable.A_CableInsulated
+        print(cable.f_SC)
+        print((self.ParametersLEDET.Inputs.wBare_inGroup*self.ParametersLEDET.Inputs.hBare_inGroup)/cable.A_CableInsulated)
         cable.f_ST = (1- self.ParametersLEDET.Inputs.f_SC_strand_inGroup) * \
                     (self.ParametersLEDET.Inputs.wBare_inGroup*self.ParametersLEDET.Inputs.hBare_inGroup)/cable.A_CableInsulated
         cable.SCtype = self.ParametersLEDET.Inputs.SCtype_inGroup
@@ -300,6 +306,7 @@ class ParameterSweep(object):
 
         vQ = self.quenchPropagationVelocity(I, B, T_bath, cable)
         self.ParametersLEDET.setAttribute(getattr(self.ParametersLEDET, "Inputs"), "vQ_iStartQuench", vQ)
+        print(vQ)
 
     def prepareSimulation(self, MagnetName, folder, cleanFolder = True,  OffsetNumber = 0, ROXIE_File = '', clean = False):
         Adjust_vQ = 0
