@@ -9,7 +9,7 @@ from steam_nb_api.resources.ResourceReader import ResourceReader
 
 @dataclass
 class LEDETInputs:
-    BlankRows: np.ndarray = np.array([[3,4,6,36,37,41,45,49,52,55,57,63,77,79],[3,4,6,36,37,41,45,49,52,55,57,63,77,79]])
+    BlankRows: np.ndarray = np.array([[3,4,6,34,35,39,43,47,50,53,55,61,75,77],[3,4,6,34,35,39,43,47,50,53,55,61,75,77]])
     T00: float= 0.0
     l_magnet: float= 0.0
     I00: float= 0.0
@@ -198,8 +198,13 @@ class ParametersLEDET:
                 currentStatus = currentStatus +1
 
             attributeCounter = attributeCounter + 1
+
         LEDETclass.BlankRows[1] = lineAdd-1
 
+        if len(LEDETclass.overwrite_f_internalVoids_inGroup) != 0:
+            LEDETclass.BlankRows[1, 3:] = LEDETclass.BlankRows[1, 3:] + 2
+
+
     def readLEDETExcel(self, file):
         ##File must be whole eos string
         workbookVariables = xlrd.open_workbook(file)
@@ -483,16 +488,23 @@ class ParametersLEDET:
             # >>> 					3rd variable x3 [2 4 6]
 
         """
+        if(variableGroup == self.variableGroupInputs):
+            variableGroup=self.Inputs
+        if (variableGroup == self.variableGroupOptions):
+            variableGroup = self.Options
+        if (variableGroup == self.variableGroupPlots):
+            variableGroup = self.Plots
+        if (variableGroup == self.variableGroupVariables):
+            variableGroup = self.Variables
+
         if(type(variableGroup) != dict):
             for k in variableGroup.__annotations__:
                 if (k == "BlankRows"): continue
+                if k == 'overwrite_f_internalVoids_inGroup': continue
+                if k == 'overwrite_f_externalVoids_inGroup': continue
                 print(variableLabels[k])
                 print(k, self.getAttribute(variableGroup, k))
         else:
-            self.variableGroupInputs = asdict(self.Inputs)
-            self.variableGroupOptions = asdict(self.Options)
-            self.variableGroupPlots = asdict(self.Plots)
-            self.variableGroupVariables = asdict(self.Variables)
             for k in variableGroup:
                 if (k == "BlankRows"): continue
                 if k =='overwrite_f_internalVoids_inGroup': continue
@@ -720,7 +732,7 @@ class ParametersLEDET:
             if (attribute == "overwrite_f_externalVoids_inGroup"):
                 ofiVg = self.getAttribute(variableGroup, attribute)
                 if len(ofiVg) == 0:
-                    currentRow = currentRow + 1
+                    #currentRow = currentRow + 1
                     continue
             if currentRow in variableGroup.BlankRows[1]:
                 currentRow = currentRow + 1
