@@ -268,56 +268,56 @@ class MagneticCoil:
         # Apply symmetry conditions to blocks
         for group in groupParametersList:
             if group.symm == 0:
-                print('Group {} has symmetry of type {} --> No symmetry.'.format(group.noGroup, group.symm))
+                if verbose: print('Group {} has symmetry of type {} --> No symmetry.'.format(group.noGroup, group.symm))
 
             elif group.symm == 2:
-                print('Group {} has symmetry of type {} --> Dipole symmetry.'.format(group.noGroup, group.symm))
+                if verbose: print('Group {} has symmetry of type {} --> Dipole symmetry.'.format(group.noGroup, group.symm))
                 blockParametersList = group.applyMultipoleSymmetry(blockParametersList, N=1)
 
             elif group.symm == 4:
-                print('Group {} has symmetry of type {} --> Quadrupole symmetry.'.format(group.noGroup, group.symm))
+                if verbose: print('Group {} has symmetry of type {} --> Quadrupole symmetry.'.format(group.noGroup, group.symm))
                 blockParametersList = group.applyMultipoleSymmetry(blockParametersList, N=2)
 
             elif group.symm == 6:
-                print('Group {} has symmetry of type {} --> Sextupole symmetry.'.format(group.noGroup, group.symm))
+                if verbose: print('Group {} has symmetry of type {} --> Sextupole symmetry.'.format(group.noGroup, group.symm))
                 blockParametersList = group.applyMultipoleSymmetry(blockParametersList, N=3)
 
             elif group.symm == 8:
-                print('Group {} has symmetry of type {} --> Octupole symmetry.'.format(group.noGroup, group.symm))
+                if verbose: print('Group {} has symmetry of type {} --> Octupole symmetry.'.format(group.noGroup, group.symm))
                 blockParametersList = group.applyMultipoleSymmetry(blockParametersList, N=4)
 
             elif group.symm == 10:
-                print('Group {} has symmetry of type {} --> Decapole symmetry.'.format(group.noGroup, group.symm))
+                if verbose: print('Group {} has symmetry of type {} --> Decapole symmetry.'.format(group.noGroup, group.symm))
                 blockParametersList = group.applyMultipoleSymmetry(blockParametersList, N=5)
 
             elif group.symm == 12:
-                print('Group {} has symmetry of type {} --> Dodecapole symmetry.'.format(group.noGroup, group.symm))
+                if verbose: print('Group {} has symmetry of type {} --> Dodecapole symmetry.'.format(group.noGroup, group.symm))
                 blockParametersList = group.applyMultipoleSymmetry(blockParametersList, N=6)
 
             elif group.symm == 31:
-                print(
+                if verbose: print(
                     'Group {} has symmetry of type {} --> Window frame dipole symmetry. Not currently supported.'.format(
                         group.noGroup, group.symm))
 
             elif group.symm == 33:
-                print(
+                if verbose: print(
                     'Group {} has symmetry of type {} --> Window frame quadrupole symmetry. Not currently supported.'.format(
                         group.noGroup, group.symm))
 
             elif group.symm == 41:
-                print('Group {} has symmetry of type {} --> Solenoid symmetry. Not currently supported.'.format(
+                if verbose: print('Group {} has symmetry of type {} --> Solenoid symmetry. Not currently supported.'.format(
                     group.noGroup,
                     group.symm))
 
             elif group.symm == 71:
-                print(
+                if verbose: print(
                     'Group {} has symmetry of type {} --> Periodic structure (wiggler) symmetry. Not currently supported.'.format(
                         group.noGroup, group.symm))
 
             else:
-                print('Group {} has symmetry of type {} --> Not currently supported.'.format(group.noGroup, group.symm))
+                if verbose: print('Group {} has symmetry of type {} --> Not currently supported.'.format(group.noGroup, group.symm))
 
-        print('Total number of blocks: {}'.format(len(blockParametersList)))
+        if verbose: print('Total number of blocks: {}'.format(len(blockParametersList)))
 
         if verbose:
             # Print each BlockParameters object in the list
@@ -345,14 +345,14 @@ class MagneticCoil:
         # Apply transformations to blocks/transformations/conductors
         for transformation in transformationParametersList:
             if transformation.string == 'SHIFT2':
-                print(
+                if verbose: print(
                     'Transformation {} applies a transformation of type {} --> Cartesian shift of x={} mm and y={} mm.'
                         .format(transformation.noTransformation, transformation.string, transformation.x,
                                 transformation.y))
                 transformation.applyTranformationShift2(blockParametersList, groupParametersList)
 
             elif transformation.string == 'ROLL2':
-                print(
+                if verbose: print(
                     'Transformation {} applies a transformation of type {} --> Counterclockwise rotation of alpha={} deg around point x={} mm and y={} mm.'
                         .format(transformation.noTransformation, transformation.string, transformation.alph,
                                 transformation.x,
@@ -360,20 +360,20 @@ class MagneticCoil:
                 transformation.applyTranformationRoll2(blockParametersList, groupParametersList)
 
             elif transformation.string == 'CONN2':
-                print(
+                if verbose: print(
                     'Transformation {} applies a transformation of type {} --> Connection of block vertices. Not currently supported.'
                         .format(transformation.noTransformation, transformation.string))
 
             elif transformation.string == 'CONN2P':
-                print(
+                if verbose: print(
                     'Transformation {} applies a transformation of type {} --> Connection of block vertices to point XY. Not currently supported.'
                         .format(transformation.noTransformation, transformation.string))
 
             else:
-                print('Transformation {} applies a transformation of type {} --> Not currently supported.'
+                if verbose: print('Transformation {} applies a transformation of type {} --> Not currently supported.'
                       .format(transformation.noTransformation, transformation.string))
 
-        print('Total number of blocks: {}'.format(len(blockParametersList)))
+        if verbose: print('Total number of blocks: {}'.format(len(blockParametersList)))
 
         if verbose:
             # Print each BlockParameters object in the list
