@@ -172,11 +172,12 @@ class ParametersCOSIM:
                 makeCopyFile(fileName_complementaryIOPortDefinition,
                              os.path.join(nameFolderCosimModel, 'LEDET'+str(i), 'LedetInputOutputPortDefinition.json'))
 
-    def makeGenericIOPortFiles(self, CoilSections, CurrentFolder, CoSimFolder: str, PSpiceExecutable: str, LEDETExecutable: str,
+    def makeGenericIOPortFiles(self, CoilSections, CoSimFolder: str, PSpiceExecutable: str, LEDETExecutable: str,
                                t_0 = [0, 2e-5], t_end = [2e-5, 0.5], t_step_max = [[1e-5, 1e-5], [1e-5, 1e-5]],
                                relTolerance = [1e-4, None], absTolerance = [1, None], executionOrder = [1, 2],
                                executeCleanRun = [True, True], N_LEDET = 1, QuenchMagnet = 0, SimulationNumber = [0], DistinctMagnets = 1, PSPICEinitialConditions = []):
 
+        CurrentFolder =  os.getcwd()
         # Components which are used in the Ports
         Components = ["L", "CoilSections"]  # [0] = PSpice, [1]=LEDET
         # Setting the Coilsections
@@ -275,7 +276,11 @@ class ParametersCOSIM:
                 filename = self.nameFolderCosimModel + '/LEDET_'+str(i)+'/LedetConfig.json'
                 with open(filename, 'r') as f:
                     data = json.load(f)
-                    data["solverPath"] = LEDETExecutable
+                    if executionOrder.count(2) > 1:
+                        idxLEDET = LEDETExecutable.find('LEDET')
+                        data["solverPath"] = LEDETExecutable[0:idxLEDET + 5] + "_"+str(i) + LEDETExecutable[idxLEDET + 5:]
+                        print('LEDET parallel solving, performed from: ', data["solverPath"])
+                    else: data["solverPath"] = LEDETExecutable
                     data["modelName"] = self.nameMagnet[i-1]
                     data["simulationNumber"] = str(SimulationNumber[i-1])
                 try:
@@ -384,7 +389,7 @@ class ParametersCOSIM:
         struct_total = []
         for n in range(0, N_LEDET):
             if n+1== QuenchMagnet and QuenchMagnet != 0:
-                quench = '_QUENCH'
+                quench = '_Quench'
             else:
                 quench = ''
             if DistinctMagnets != 1:
@@ -439,10 +444,28 @@ class ParametersCOSIM:
                 json.dump(struct_total[i], f, indent=4)
                 f.write('\n')
 
-    def copyCOSIMfiles(self, circuit, nameFileSING, StimulusFile, LEDETFiles, nameMagnet,N_LEDET=1):
+    def FindLibPath(self, File):
+        path = os.path.abspath(os.path.join(os.getcwd(), os.pardir))
+        for i in range(5):
+            if os.path.isdir(os.path.join(path,"steam-pspice-library")):
+               return  os.path.join(path,File)
+            else:
+                path =  os.path.abspath(os.path.join(path, os.pardir))
+        print("Could not find PSPICE library. Please add manually.")
+        return False
+
+    def copyCOSIMfiles(self, nameFileSING, StimulusFile, nameMagnet, N_LEDET=1, ManuallyStimulusFile = ''):
+
+        LEDETFiles = os.path.abspath(os.path.join(os.path.abspath(os.path.join(os.getcwd(), os.pardir)),os.pardir))
+        LEDETFiles = os.path.join(LEDETFiles, "steam-ledet-input")
         nameFolderCosimModel = self.nameFolderCosimModel
-        #print(nameFolderCosimModel)
+
         # Copy PSPICE model file
+        if len(ManuallyStimulusFile) == 0:
+            StimulusFile = self.FindLibPath(StimulusFile)
+            if StimulusFile == False: return
+        else:
+            StimulusFile = ManuallyStimulusFile
         nameFolderPSpiceModel = os.path.join(nameFolderCosimModel, 'PSpice')
         if not os.path.isdir(nameFolderPSpiceModel):
             os.mkdir(nameFolderPSpiceModel)
@@ -453,18 +476,17 @@ class ParametersCOSIM:
         for i in range(N_LEDET):
             if N_LEDET > 1:
                 nameFolderLedetModel = os.path.join(nameFolderCosimModel, 'LEDET_'+str(i+1))
-                if len(LEDETFiles)>1:
-                    sourcedir = LEDETFiles[i]
-                    sourcefiles = os.listdir(LEDETFiles[i])
+                if len(nameMagnet)>1:
+                    sourcedir = os.path.join(LEDETFiles, nameMagnet[i])
+                    nM = nameMagnet[i]
                 else:
-                    sourcefiles = os.listdir(LEDETFiles)
-                    sourcedir = LEDETFiles
-                nM = nameMagnet[i]
+                    sourcedir = os.path.join(LEDETFiles, nameMagnet)
+                    nM = nameMagnet
             else:
+                sourcedir = os.path.join(LEDETFiles, nameMagnet)
                 nameFolderLedetModel = os.path.join(nameFolderCosimModel, 'LEDET')
-                sourcefiles = os.listdir(LEDETFiles)
                 nM = nameMagnet
-                sourcedir = LEDETFiles
+            sourcefiles = os.listdir(sourcedir)
             if not os.path.isdir(nameFolderLedetModel):
                 os.mkdir(nameFolderLedetModel)
             destinationpath_field = nameFolderLedetModel + "//Field maps//" + nM
@@ -474,13 +496,9 @@ class ParametersCOSIM:
                     makeCopyFile(os.path.join(sourcedir, file), os.path.join(destinationpath_field, file))
                 if file.endswith('.xlsx') and not file.startswith(".sys") and file.startswith(str(nM)):
                     shutil.copy(os.path.join(sourcedir, file), os.path.join(destinationpath_para, file))
-                    if len(LEDETFiles) > 1:
-                        LEDET_Fs.append(LEDETFiles[i]+file)
-                    else:
-                        LEDET_Fs.append(LEDETFiles+file)
+                    LEDET_Fs.append(os.path.join(destinationpath_para, file))
                 if file.endswith('_selfMutualInductanceMatrix.csv'):
                     shutil.copy(os.path.join(sourcedir, file), os.path.join(destinationpath_para, file))
-
         return LEDET_Fs
 
     def prepareLEDETFiles(self, files, N_PAR=1):
@@ -507,7 +525,7 @@ class ParametersCOSIM:
     def prepareSingleLEDETFile(self, file):
         a = ParametersLEDET()
         a.readLEDETExcel(file)
-        a.Options.flag_useExternalInitialization = 0
+        a.Options.flag_useExternalInitialization = 1
         a.Options.flag_generateReport = 0
         a.Options.flag_saveMatFile = 0
         a.writeFileLEDET(file)
